@@ -1,5 +1,5 @@
 package Rex::Dondley::ProcessTaskArgs ;
-$Rex::Dondley::ProcessTaskArgs::VERSION = '0.008';
+$Rex::Dondley::ProcessTaskArgs::VERSION = '0.009';
 use strict;
 use warnings;
 
@@ -45,8 +45,6 @@ sub process_task_args {
       $valid_keys{$arg} = 0;
     }
   } else {
-    use Data::Dumper qw(Dumper);
-    print STDERR Dumper \@valid_args;
     %valid_keys = @valid_args;
   }
 
@@ -118,7 +116,7 @@ Rex::Dondley::ProcessTaskArgs - easier Rex task argument handling
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
